@@ -153,6 +153,15 @@ def test_find_sub_elements_list(finder: FinderPage):
         break
 
 
+def test_inexistent_sub_element(finder: FinderPage):
+    finder.open("https://testpages.herokuapp.com/styled/find-by-playground-test.html")
+
+    # Sub elements
+    div = finder.find("#div1")
+    inexistent = div.find("#inexistent")
+    inexistent.expect.count.be(0)
+
+
 def test_form(finder: FinderPage):
     finder.open("https://testpages.herokuapp.com/styled/basic-html-form-test.html")
 
@@ -181,8 +190,15 @@ def test_form(finder: FinderPage):
 def test_screenshot(finder: FinderPage):
     finder.open("https://testpages.herokuapp.com/styled/find-by-playground-test.html")
     p = finder.find(By.id("pre1").unique)
+
     path = p.take_screenshot()
-    assert path
+    assert finder.webdriver.session_id in path.name
+    assert path.exists()
+
+    path = p.take_screenshot("test")
+    assert finder.webdriver.session_id not in path.name
+    assert "test" in path.name
+    assert path.exists()
 
 
 def test_retry(finder: FinderPage):
@@ -316,9 +332,26 @@ def test_count_nonexistent_fails(finder: FinderPage):
             unknown.expect.count.be(1)
 
 
-def test_empty_ui_element():
+def test_inexistent_ui_element_wrapper():
     empty_ui_element = InexistentUiElement()
     empty_ui_element.expect.count.be(0)
+    assert empty_ui_element.webdriver is None
+    empty_ui_element.scroll_to_top()
+    empty_ui_element.scroll_into_view()
+    empty_ui_element.highlight()
+    empty_ui_element.click()
+    empty_ui_element.hover()
+    empty_ui_element.long_click()
+    empty_ui_element.double_click()
+    empty_ui_element.drag_and_drop_to(empty_ui_element)
+    empty_ui_element.send_keys("test")
+    empty_ui_element.type("test")
+    empty_ui_element.clear()
+    empty_ui_element.submit()
+    assert empty_ui_element.take_screenshot() is None
+    assert isinstance(empty_ui_element.find("#inexistent"), InexistentUiElement)
+    for e in empty_ui_element:
+        assert False
 
 
 def teardown_module():
